API
====

autopew\.transform
------------------------

 .. automodule:: autopew.transform

 .. toctree::
    :maxdepth: 2

    api/transform


autopew\.image
------------------------

  .. automodule:: autopew.image

  .. toctree::
    :maxdepth: 2

    api/image


autopew\.graph
------------------------

  .. automodule:: autopew.graph

  .. toctree::
    :maxdepth: 2

    api/graph


autopew\.io
------------------------

  .. automodule:: autopew.io

  .. toctree::
    :maxdepth: 2

    api/io


autopew\.gui
------------------------

  .. toctree::
    :maxdepth: 2

    api/gui


autopew\.util
------------------------

  .. automodule:: autopew.util
    :members:
    :undoc-members:


  .. toctree::
    :maxdepth: 2

    api/util
